Module checksig

Module checksig 

Enums

PubKeyCheckResult

Constants

SIGHASH_ALL
SIGHASH_ANYONECANPAY
SIGHASH_DEFAULT
SIGHASH_NONE
SIGHASH_SINGLE
SIG_HASH_TYPES
hash types that can appear at the end of a signature (SIGHASH_DEFAULT can’t)

Functions

check_pub_key
is_valid_signature_encoding
A canonical signature exists of: <30> <02> <02> Where R and S are not negative (their first byte has its highest bit not set), and not excessively padded (do not start with a 0 byte, unless an otherwise negative number follows, in which case a single 0 byte is necessary and even required).