Enums
Constants
- SIGHASH_
ALL - SIGHASH_
ANYONECANPAY - SIGHASH_
DEFAULT - SIGHASH_
NONE - SIGHASH_
SINGLE - SIG_
HASH_ TYPES - hash types that can appear at the end of a signature (SIGHASH_DEFAULT can’t)
Functions
- check_
pub_ key - is_
valid_ signature_ encoding - A canonical signature exists of: <30>
<02> <02> Where R and S are not negative (their first byte has its highest bit not set), and not excessively padded (do not start with a 0 byte, unless an otherwise negative number follows, in which case a single 0 byte is necessary and even required).